pub struct AggregateChildSpecBuilder { /* private fields */ }Expand description
Builder for AggregateChildSpec.
Implementations
Sourceimpl AggregateChildSpecBuilder
impl AggregateChildSpecBuilder
Sourcepub fn psome_likelihood<VALUE: Into<u8>>(self, value: VALUE) -> Self
pub fn psome_likelihood<VALUE: Into<u8>>(self, value: VALUE) -> Self
Set the psome_likelihood field to indicate the probability this child (if optional) is something as opposed to nothing.
This field has no meaning if optional is *false.
Values may be 0..100 inclusive. Values over this maximum will be clipped.
Sourcepub fn optional<VALUE: Into<bool>>(self, value: VALUE) -> Self
pub fn optional<VALUE: Into<bool>>(self, value: VALUE) -> Self
Set the optional field to indicate whether or not this tree branch is optional.
Sourcepub fn build(self) -> Result<AggregateChildSpec, AggregateChildSpecBuilderError>
pub fn build(self) -> Result<AggregateChildSpec, AggregateChildSpecBuilderError>