pub struct DepthBasedNodeVariantPolicy { /* private fields */ }Expand description
This picks which variant to use based on current depth.
- levels < aggregator_start_level => dispatch
- aggregator_start_level..(leaf_start_level) => aggregator
- leaf_start_level.. => leaf
Implementations
Sourceimpl DepthBasedNodeVariantPolicy
impl DepthBasedNodeVariantPolicy
Sourcepub fn aggregator_start_level(&self) -> &u8
pub fn aggregator_start_level(&self) -> &u8
This field specifies the level of our tree at which aggregator nodes start
Sourcepub fn leaf_start_level(&self) -> &u8
pub fn leaf_start_level(&self) -> &u8
This field specifies the level of our tree at which leaf nodes start