pub struct LevelSkippingConfiguration { /* private fields */ }Expand description
This struct should define how you skip certain levels early, turning them into leaves based on probabilities.
Implementations
Sourceimpl LevelSkippingConfiguration
impl LevelSkippingConfiguration
Sourcepub fn leaf_probability_per_level(&self) -> &Vec<f32>
pub fn leaf_probability_per_level(&self) -> &Vec<f32>
This array of fractions [0..1] should specify the chance that a node at level i is a leaf.
e.g. [0.0, 0.2, 0.4] → level 2 has 20% chance of skipping deeper expansion, etc.