pub struct TreeLevelSpecificConfigurationBuilder { /* private fields */ }Expand description
Builder for TreeLevelSpecificConfiguration.
Implementations
Sourceimpl TreeLevelSpecificConfigurationBuilder
impl TreeLevelSpecificConfigurationBuilder
Sourcepub fn breadth_per_level<VALUE>(
self,
value: VALUE,
) -> TreeLevelSpecificConfigurationBuilder
pub fn breadth_per_level<VALUE>( self, value: VALUE, ) -> TreeLevelSpecificConfigurationBuilder
This array should map each level to a breadth override, e.g. [3,4,6].
If length > depth, it’s invalid. Larger numbers → more sibling nodes at that level.
Sourcepub fn density_per_level<VALUE>(
self,
value: VALUE,
) -> TreeLevelSpecificConfigurationBuilder
pub fn density_per_level<VALUE>( self, value: VALUE, ) -> TreeLevelSpecificConfigurationBuilder
This array should map each level to a density override, e.g. [2,3,5].
If length > depth, it’s invalid. Higher numbers → more variants at leaf nodes at that level.
Sourcepub fn build(
self,
) -> Result<TreeLevelSpecificConfiguration, TreeLevelSpecificConfigurationBuilderError>
pub fn build( self, ) -> Result<TreeLevelSpecificConfiguration, TreeLevelSpecificConfigurationBuilderError>