pub struct WeightedNodeVariantPolicyWithLimits { /* private fields */ }Expand description
This policy is the same as Weighted, but with built-in depth constraints to forbid aggregator or dispatch nodes beyond a certain depth. We can use it to forbid leaves before a certain depth.
Implementations
Sourceimpl WeightedNodeVariantPolicyWithLimits
impl WeightedNodeVariantPolicyWithLimits
Sourcepub fn aggregator_weight(&self) -> &f32
pub fn aggregator_weight(&self) -> &f32
Probability weight for aggregator selection
Sourcepub fn dispatch_weight(&self) -> &f32
pub fn dispatch_weight(&self) -> &f32
Probability weight for dispatch selection
Sourcepub fn leaf_holder_weight(&self) -> &f32
pub fn leaf_holder_weight(&self) -> &f32
Probability weight for leaf-holder selection
Sourcepub fn aggregator_max_depth(&self) -> &Option<u8>
pub fn aggregator_max_depth(&self) -> &Option<u8>
Aggregator disallowed deeper than this level (if set).
Sourcepub fn dispatch_max_depth(&self) -> &Option<u8>
pub fn dispatch_max_depth(&self) -> &Option<u8>
Dispatch disallowed deeper than this level (if set).
Sourcepub fn leaf_min_depth(&self) -> &Option<u8>
pub fn leaf_min_depth(&self) -> &Option<u8>
Leaf-holder disallowed before this level (if set).