pub struct JustifiedGrowerTreeConfiguration { /* private fields */ }Implementations
Sourceimpl JustifiedGrowerTreeConfiguration
impl JustifiedGrowerTreeConfiguration
pub fn target_name(&self) -> &String
pub fn target_name_confidence(&self) -> &f64
pub fn target_name_justification(&self) -> &String
pub fn depth(&self) -> &u8
pub fn depth_confidence(&self) -> &f64
pub fn depth_justification(&self) -> &String
pub fn breadth(&self) -> &u8
pub fn breadth_confidence(&self) -> &f64
pub fn breadth_justification(&self) -> &String
pub fn density(&self) -> &u8
pub fn density_confidence(&self) -> &f64
pub fn density_justification(&self) -> &String
pub fn leaf_granularity(&self) -> &f32
pub fn leaf_granularity_confidence(&self) -> &f64
pub fn leaf_granularity_justification(&self) -> &String
pub fn balance_symmetry(&self) -> &f32
pub fn balance_symmetry_confidence(&self) -> &f64
pub fn balance_symmetry_justification(&self) -> &String
pub fn complexity(&self) -> &JustifiedConfigurationComplexity
pub fn complexity_confidence(&self) -> &f64
pub fn complexity_justification(&self) -> &String
pub fn level_specific(&self) -> &Option<JustifiedTreeLevelSpecificConfiguration>
pub fn level_specific_confidence(&self) -> &f64
pub fn level_specific_justification(&self) -> &String
pub fn weighted_branching( &self, ) -> &Option<JustifiedWeightedBranchingConfiguration>
pub fn weighted_branching_confidence(&self) -> &f64
pub fn weighted_branching_justification(&self) -> &String
pub fn level_skipping(&self) -> &Option<JustifiedLevelSkippingConfiguration>
pub fn level_skipping_confidence(&self) -> &f64
pub fn level_skipping_justification(&self) -> &String
pub fn capstone(&self) -> &Option<JustifiedCapstoneGenerationConfiguration>
pub fn capstone_confidence(&self) -> &f64
pub fn capstone_justification(&self) -> &String
pub fn ordering(&self) -> &Option<JustifiedSubBranchOrdering>
pub fn ordering_confidence(&self) -> &f64
pub fn ordering_justification(&self) -> &String
pub fn ai_confidence( &self, ) -> &Option<JustifiedAiTreeBranchingConfidenceConfiguration>
pub fn ai_confidence_confidence(&self) -> &f64
pub fn ai_confidence_justification(&self) -> &String
pub fn aggregator_preference(&self) -> &f32
pub fn aggregator_preference_confidence(&self) -> &f64
pub fn aggregator_preference_justification(&self) -> &String
pub fn allow_early_leaves(&self) -> &bool
pub fn allow_early_leaves_confidence(&self) -> &f64
pub fn allow_early_leaves_justification(&self) -> &String
pub fn partial_subbranch_probability(&self) -> &f32
pub fn partial_subbranch_probability_confidence(&self) -> &f64
pub fn partial_subbranch_probability_justification(&self) -> &String
pub fn tree_expansion_policy(&self) -> &JustifiedTreeExpansionPolicy
pub fn tree_expansion_policy_confidence(&self) -> &f64
pub fn tree_expansion_policy_justification(&self) -> &String
pub fn aggregator_depth_limit(&self) -> &Option<u8>
pub fn aggregator_depth_limit_confidence(&self) -> &f64
pub fn aggregator_depth_limit_justification(&self) -> &String
pub fn dispatch_depth_limit(&self) -> &Option<u8>
pub fn dispatch_depth_limit_confidence(&self) -> &f64
pub fn dispatch_depth_limit_justification(&self) -> &String
pub fn leaf_min_depth(&self) -> &Option<u8>
pub fn leaf_min_depth_confidence(&self) -> &f64
pub fn leaf_min_depth_justification(&self) -> &String
Sourceimpl JustifiedGrowerTreeConfiguration
impl JustifiedGrowerTreeConfiguration
pub fn set_target_name( &mut self, val: String, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_target_name_confidence( &mut self, val: f64, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_target_name_justification( &mut self, val: String, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_depth(&mut self, val: u8) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_depth_confidence( &mut self, val: f64, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_depth_justification( &mut self, val: String, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_breadth(&mut self, val: u8) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_breadth_confidence( &mut self, val: f64, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_breadth_justification( &mut self, val: String, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_density(&mut self, val: u8) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_density_confidence( &mut self, val: f64, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_density_justification( &mut self, val: String, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_leaf_granularity( &mut self, val: f32, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_leaf_granularity_confidence( &mut self, val: f64, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_leaf_granularity_justification( &mut self, val: String, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_balance_symmetry( &mut self, val: f32, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_balance_symmetry_confidence( &mut self, val: f64, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_balance_symmetry_justification( &mut self, val: String, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_complexity( &mut self, val: JustifiedConfigurationComplexity, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_complexity_confidence( &mut self, val: f64, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_complexity_justification( &mut self, val: String, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_level_specific( &mut self, val: Option<JustifiedTreeLevelSpecificConfiguration>, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_level_specific_confidence( &mut self, val: f64, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_level_specific_justification( &mut self, val: String, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_weighted_branching( &mut self, val: Option<JustifiedWeightedBranchingConfiguration>, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_weighted_branching_confidence( &mut self, val: f64, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_weighted_branching_justification( &mut self, val: String, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_level_skipping( &mut self, val: Option<JustifiedLevelSkippingConfiguration>, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_level_skipping_confidence( &mut self, val: f64, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_level_skipping_justification( &mut self, val: String, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_capstone( &mut self, val: Option<JustifiedCapstoneGenerationConfiguration>, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_capstone_confidence( &mut self, val: f64, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_capstone_justification( &mut self, val: String, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_ordering( &mut self, val: Option<JustifiedSubBranchOrdering>, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_ordering_confidence( &mut self, val: f64, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_ordering_justification( &mut self, val: String, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_ai_confidence( &mut self, val: Option<JustifiedAiTreeBranchingConfidenceConfiguration>, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_ai_confidence_confidence( &mut self, val: f64, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_ai_confidence_justification( &mut self, val: String, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_aggregator_preference( &mut self, val: f32, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_aggregator_preference_confidence( &mut self, val: f64, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_aggregator_preference_justification( &mut self, val: String, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_allow_early_leaves( &mut self, val: bool, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_allow_early_leaves_confidence( &mut self, val: f64, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_allow_early_leaves_justification( &mut self, val: String, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_partial_subbranch_probability( &mut self, val: f32, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_partial_subbranch_probability_confidence( &mut self, val: f64, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_partial_subbranch_probability_justification( &mut self, val: String, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_tree_expansion_policy( &mut self, val: JustifiedTreeExpansionPolicy, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_tree_expansion_policy_confidence( &mut self, val: f64, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_tree_expansion_policy_justification( &mut self, val: String, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_aggregator_depth_limit( &mut self, val: Option<u8>, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_aggregator_depth_limit_confidence( &mut self, val: f64, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_aggregator_depth_limit_justification( &mut self, val: String, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_dispatch_depth_limit( &mut self, val: Option<u8>, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_dispatch_depth_limit_confidence( &mut self, val: f64, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_dispatch_depth_limit_justification( &mut self, val: String, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_leaf_min_depth( &mut self, val: Option<u8>, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_leaf_min_depth_confidence( &mut self, val: f64, ) -> &mut JustifiedGrowerTreeConfiguration
pub fn set_leaf_min_depth_justification( &mut self, val: String, ) -> &mut JustifiedGrowerTreeConfiguration
Sourceimpl JustifiedGrowerTreeConfiguration
impl JustifiedGrowerTreeConfiguration
Sourcepub fn stamp(&self) -> String
pub fn stamp(&self) -> String
This method is just an alias for produce_concrete_growth_instructions
Sourcepub fn produce_concrete_growth_instructions(&self) -> String
pub fn produce_concrete_growth_instructions(&self) -> String
Produces a coherent, human-readable set of instructions describing exactly how to grow a tree that conforms to this configuration, assuming no prior knowledge from the reader.
It includes a descriptive explanation for each relevant parameter, explaining both what the parameter means and why this particular value matters for shaping the resulting tree.
Fields or sub-configurations which are not set (i.e. None) are omitted from the instructions.
Enum variants that were not chosen are also omitted.